import { onMount } from "solid-js";
import { Scene, PointLayer, PolygonLayer, LineLayer, Marker } from '@antv/l7';
import { Mapbox } from '@antv/l7-maps';
// import { GaodeMap } from '@antv/l7-maps';
// import DataSet from '@antv/data-set';

// import json from "../../../assets/file/100000_full.json"

import utils from "../../../utils/index"
import config from "../../../base/config"

import { getGeography, getMapfull } from "../../../api/bigScreen"

import "../../../assets/style/BigScreenHome.css"


function Map(prop) {
    let $canvas = undefined,
        timeHome = undefined,
        source = [],
        index = 0,
        anchorLayer = undefined,
        textLayer = undefined,
        li = [],
        scene = undefined;

    // TODO: 高德地图
    /***
     * 高德天气，暂时不用只能在https下可以
     */
    function getWatcher(local) {
        getGeography({
            radius: 1,
            key: config.webToke,
            location: [local.lng, local.lat].join()
        }).then(res => {
            let adcode = res.regeocode.addressComponent.adcode.split("");
            getWeather({
                key: config.webToke,
                // city: adcode[0] + adcode[1] + adcode[2] + adcode[3] + "00"
                city: 610100
            }).then(r => prop.setfun(r))
        })
    }
    function TrendChart() {
        scene = new Scene({
            id: $canvas,
            logoVisible: false,
            // map: new GaodeMap({
            //     style: 'blank',
            //     pitch: 50,
            //     zoom: 3,
            //     maxZoom: 7,
            //     minZoom: 7,
            //     token: config.gaodeToken
            // })
            map: new Mapbox({
                pitch: 30,
                style: 'blank',
                zoom: 5.6,
                rotateEnable: true,

            })
        });


        scene.on('loaded', () => {
            scene.setCenter([108.2, 35])
            // 获取地理/天气信息
            // AMap.convertFrom([prop.Geography.longitude, prop.Geography.latitude], 'gps', function (status, result) {
            //     if (result.info !== 'ok') return
            //     console.log(result)
            //     const local = result.locations[0] || { Q: -190, R: -190, lat: -190, lng: -1906 }
            //     scene.setCenter([local.lng, local.lat])
            //     getWatcher(local)
            // });
            getMapfull().then(data => {
                li = data && data.features && data.features.length ? data.features : [];
                for (let i = 0; i < li.length; i++) {
                    const v = li[i].properties || { center: [] };
                    const Data = {
                        name: v.name,
                        lng: v.center[0],
                        lat: v.center[1],
                        size: prop.li.find(item => item.area === v.name).usrcount, // 自定义数据
                    };
                    source.push(Data);
                }
                console.log(source[index])
                const layer = new PointLayer()
                    .source(source, {
                        parser: {
                            type: 'json',
                            x: 'lng',
                            y: 'lat'
                        }
                    })
                    .shape('circle')
                    .color('backgoundColor')
                    .size(42);
                // 上层线条
                const lineUp = new LineLayer({ zIndex: 3, blend: "normal" })
                    .source(data)
                    .shape('line')
                    .color('rgb(0,255,255)')
                    .size(0.5)
                    .style({
                        raisingHeight: 150000
                    })
                    .animate({
                        interval: 1, // 间隔
                        duration: 1, // 持续时间，延时
                        trailLength: 3 // 流线长度
                    });
                //  围栏
                const bottomLayer = new LineLayer({ zIndex: 0, blend: "normal" })
                    .source(data)
                    .shape('wall')
                    .color('rgb(0,255,255)')
                    .size(10)
                    .style({
                        raisingHeight: 0,
                        heightfixed: true,
                        opacity: 1,
                        sourceColor: '#0DCCFF',
                    });
                // 高度
                const gd = new PolygonLayer({ zIndex: 1, blend: "normal" })
                    .source(data)
                    .size(150000)
                    .shape('extrude')
                    .color("name", [
                        '#87CEFA',
                        '#00BFFF',

                        '#7FFFAA',
                        '#00FF7F',
                        '#32CD32',

                        '#F0E68C',
                        '#FFD700',

                        '#FF7F50',
                        '#FF6347',
                        '#FF0000'
                    ])
                    .style({
                        heightfixed: true,
                        pickLight: true,
                        raisingHeight: 10000,
                        opacity: 0.8
                    });

                // 水波
                const waveLayer = new PointLayer({ zIndex: 4, blend: 'normal' })
                    .source(source,
                        {
                            parser: {
                                type: 'json',
                                x: 'lng',
                                y: 'lat'
                            }
                        }
                    )
                    .shape('circle')
                    .color('rgb(22, 119, 255)')
                    .size('size', v => v)
                    .animate(true)
                    .style({
                        raisingHeight: 10000,
                        unit: 'meter'
                    });

                // 柱子
                const barLayer = new PointLayer({ zIndex: 2, depth: false })
                    .source(
                        [
                            { lng: 113, lat: 29, size: 10000 },
                            { lng: 113.5, lat: 29.5, size: 30000 },

                            { lng: 110.23681640625, lat: 29.64509464986076, size: 74020.50373907911 }, { lng: 115.01586914062499, lat: 26.88777988202911, size: 22908.885529976185 }, { lng: 111.181640625, lat: 28.724313406473463, size: 73359.37302978932 }, { lng: 112.686767578125, lat: 29.257648503615542, size: 18500.90838085843 }, { lng: 114.664306640625, lat: 28.98892237190413, size: 20293.183968726793 }, { lng: 113.90075683593749, lat: 28.17855984939698, size: 18051.412077639496 }, { lng: 111.51123046875, lat: 27.45466493898314, size: 37645.94186119526 }, { lng: 110.67626953125, lat: 28.004101830368654, size: 4214.588023703825 }, { lng: 114.43359375, lat: 29.477861195816843, size: 61722.01580332115 }, { lng: 110.445556640625, lat: 26.96124577052697, size: 70806.75519747598 }, { lng: 113.75244140624999, lat: 27.88278388425912, size: 70930.24993464859 }
                        ],
                        {
                            parser: {
                                type: 'json',
                                x: 'lng',
                                y: 'lat'
                            }
                        }
                    )
                    .shape('cylinder')
                    .color('rgb(22, 119, 255)')
                    .size('size', v => [5, 5, v / 350])
                    .animate(true)
                    .style({
                        opacityLinear: {
                            enable: true, // true - false
                            dir: 'up' // up - down
                        },
                        lightEnable: false
                    });
                scene.addLayer(barLayer);
                scene.addLayer(waveLayer);
                scene.addLayer(gd);
                scene.addLayer(bottomLayer);
                scene.addLayer(layer);
                scene.addLayer(lineUp);

                timeout()
                mapFun();
            })
        });
    }

    function mapFun() {
        if (timeHome) clearTimeout(timeHome);
        timeHome = setTimeout(() => {
            timeout(scene)
        }, 3000);
    }

    function timeout() {
        // scene.setCenter([source[index].lng, source[index].lat])
        mapFun(scene);
        anchorLayer && scene.removeAllMakers();
        textLayer && scene.removeLayer(textLayer);
        var el = document.createElement('div'), son = document.createElement('div');
        el.className = 'tooltip';
        son.className = "tooltipSon";
        son.innerHTML = `<div>${source[index].name}</div>${utils.formatNumber(source[index].size, 2)}`;
        el.appendChild(son);
        // toolpit
        anchorLayer = new Marker({
            element: el
        }).setLnglat([source[index].lng, source[index].lat]);

        const text = [], province = [];
        for (let i = 0; i < source.length; i++) {
            if (index === i) {
                li[i].value = 10000 * Math.random();
                li[i] && province.push(li[i]);
                continue
            }
            const v = source[i];
            text.push(v);
        }
        // 文字
        textLayer = new PointLayer({ zIndex: 1, blend: "normal" })
            .source(text, {
                parser: {
                    type: 'json',
                    x: 'lng',
                    y: 'lat'
                }
            })
            .shape('name', 'text')
            .size(14)
            .style({
                textAnchor: 'center', // 文本相对锚点的位置 center|left|right|top|bottom|top-left
                spacing: 2, // 字符间距
                padding: [1, 1], // 文本包围盒 padding [水平，垂直]，影响碰撞检测结果，避免相邻文本靠的太近
                stroke: '#FFFFFF', // 描边颜色
                strokeWidth: 0.2, // 描边宽度
                raisingHeight: 90000,
                textAllowOverlap: true
            });
        scene.addLayer(textLayer);
        scene.addMarker(anchorLayer);

        if (source[index + 1]) index++
        else index = 0;
    }
    onMount(() => {
        TrendChart()
    })
    return (
        <div className="livRang map" style={`width:${prop.width}px;`}>
            <div className="head">{prop.title}</div>
            <div ref={$canvas} style={`width:${prop.width}px;height:${prop.height}px;position: relative;`}></div>
        </div>
    );
}

export default Map;
